package com.link.base.kafkalogrecord.service;

import com.alibaba.fastjson.JSONObject;
import com.link.base.kafkalogrecord.dao.mybatis.mapper.KafkaLogRecordMapper;
import com.link.base.kafkalogrecord.model.KafkaLogRecord;
import com.link.core.basic.dao.mapper.BasicMapper;
import com.link.core.basic.service.BasicServiceException;
import com.link.core.basic.service.BasicServiceImpl;
import com.link.core.cllog.LCLogger;
import com.link.core.objlocalhandle.kafka.KafkaEvent;
import com.link.core.objlocalhandle.kafka.ObjLocalKafkaUtils;
import com.link.core.util.CoreYmlConstants;
import com.link.core.util.PropertyUtil;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import javax.annotation.Resource;
import org.springframework.stereotype.Service;

@Service
public class KafkaLogRecordServiceImpl extends BasicServiceImpl<KafkaLogRecord> implements KafkaLogRecordService {
   @Resource
   private KafkaLogRecordMapper kafkaLogRecordMapper;
   private static final String KAFKA_LOG_INFO = "Info";
   private static final String KAFKA_LOG_ERROR = "Error";
   private static final String KAFKA_LOG_START = "New";
   private static final String KAFKA_LOG_END = "End";
   private static final String KAFKA_LOG_AFRESH = "Afresh";
   public static final String WX_SUBSCRIBER_TOPIC = "wx_subscriber_topic";

   public BasicMapper<KafkaLogRecord> getBasicMapper() {
      return this.kafkaLogRecordMapper;
   }

   public List<KafkaLogRecord> insertStartLog(String moduleName, String topicName, List<String> records) {
      List<KafkaLogRecord> kafkaLogRecords = new ArrayList();

      KafkaLogRecord record;
      try {
         for(Iterator var10 = records.iterator(); var10.hasNext(); kafkaLogRecords.add(record)) {
            String content = (String)var10.next();
            record = new KafkaLogRecord();
            record.setModuleName(moduleName);
            record.setTopicName(topicName);
            record.setMsgContent(content);
            record.setStatus("New");
            if (record.getId() == null) {
               record.setId(this.keyGenerateService.keyGenerate());
            }

            if ("Y".equals(CoreYmlConstants.getLogToES())) {
               KafkaEvent kafkaEvent = KafkaEvent.build().topic("KAFKA_ES_LOG").event(JSONObject.toJSONString(record));
               ObjLocalKafkaUtils.publish(kafkaEvent);
            } else {
               this.kafkaLogRecordMapper.insertLog(record);
            }
         }
      } catch (Exception var9) {
         Exception e = var9;
         LCLogger.withException("【kafka日志记录报错】：" + e.getMessage());
      }

      return kafkaLogRecords;
   }

   public void insertEndLog(List<KafkaLogRecord> kafkaLogRecords) {
      try {
         Iterator var7 = kafkaLogRecords.iterator();

         while(var7.hasNext()) {
            KafkaLogRecord kafkaLogRecord = (KafkaLogRecord)var7.next();
            kafkaLogRecord.setStatus("End");
            String kafkaLogLevel = PropertyUtil.getCommonProperty("lj_kafka_log_level");
            if (kafkaLogRecord.getId() == null) {
               throw new BasicServiceException("kafka记录日志结束异常，无日志记录Id！");
            }

            if ("Y".equals(CoreYmlConstants.getLogToES())) {
               KafkaEvent kafkaEvent = KafkaEvent.build().topic("KAFKA_ES_LOG").event(JSONObject.toJSONString(kafkaLogRecord));
               ObjLocalKafkaUtils.publish(kafkaEvent);
            } else {
               this.kafkaLogRecordMapper.updateLog(kafkaLogRecord);
            }
         }
      } catch (Exception var6) {
         Exception e = var6;
         LCLogger.withException("【kafka日志记录报错】：" + e.getMessage());
      }

   }

   public void insertErrorLog(List<KafkaLogRecord> kafkaLogRecords) {
      try {
         Iterator var6 = kafkaLogRecords.iterator();

         while(var6.hasNext()) {
            KafkaLogRecord kafkaLogRecord = (KafkaLogRecord)var6.next();
            kafkaLogRecord.setStatus("Error");
            if ("Y".equals(CoreYmlConstants.getLogToES())) {
               if (kafkaLogRecord.getId() == null) {
                  kafkaLogRecord.setId(this.keyGenerateService.keyGenerate());
               }

               KafkaEvent kafkaEvent = KafkaEvent.build().topic("KAFKA_ES_LOG").event(JSONObject.toJSONString(kafkaLogRecord));
               ObjLocalKafkaUtils.publish(kafkaEvent);
            } else if (kafkaLogRecord.getId() == null) {
               kafkaLogRecord.setId(this.keyGenerateService.keyGenerate());
               this.kafkaLogRecordMapper.insertLog(kafkaLogRecord);
            } else {
               this.kafkaLogRecordMapper.updateLog(kafkaLogRecord);
            }
         }
      } catch (Exception var5) {
         Exception e = var5;
         LCLogger.withException("【kafka日志记录报错】：" + e.getMessage());
      }

   }
}
